@@ -31,6 +31,14 @@
 
 #define LOG_DOMAIN "ffmpeg_audio"
 
+/* Different decoding functions */
+
+#if LIBAVCODEC_BUILD >= 3349760
+#define DECODE_FUNC avcodec_decode_audio2
+#else
+#define DECODE_FUNC avcodec_decode_audio
+#endif
+
 /* The following code was ported from gmerlin_avdecoder (http://gmerlin.sourceforge.net) */
 
 /* MPEG Audio header parsing code */
@@ -304,8 +312,7 @@ static int lqt_ffmpeg_delete_audio(quicktime_audio_map_t *vtrack)
     {
     if(codec->initialized)
       avcodec_close(codec->avctx);
-    else
-      free(codec->avctx);
+    av_free(codec->avctx);
     }
   if(codec->sample_buffer) free(codec->sample_buffer);
   if(codec->chunk_buffer)  free(codec->chunk_buffer);
@@ -316,8 +323,8 @@ static int lqt_ffmpeg_delete_audio(quicktime_audio_map_t *vtrack)
 
 static int set_parameter(quicktime_t *file, 
                   int track, 
-                  char *key, 
-                  void *value)
+                  const char *key, 
+                  const void *value)
   {
   quicktime_ffmpeg_audio_codec_t *codec = ((quicktime_codec_t*)file->atracks[track].codec)->priv;
   lqt_ffmpeg_set_parameter(codec->avctx, key, value);
@@ -332,6 +339,7 @@ static int decode_chunk_vbr(quicktime_t * file, int track)
   int chunk_packets, i, num_samples, bytes_decoded;
   int packet_size, packet_samples;
   int frame_bytes;
+  int new_samples;
   quicktime_audio_map_t *track_map = &(file->atracks[track]);
   quicktime_ffmpeg_audio_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
 
@@ -339,11 +347,14 @@ static int decode_chunk_vbr(quicktime_t * file, int track)
 
   if(!chunk_packets)
     return 0;
+
+  new_samples = num_samples + AVCODEC_MAX_AUDIO_FRAME_SIZE / (2 * track_map->channels);
   
-  if(codec->sample_buffer_alloc < codec->sample_buffer_end - codec->sample_buffer_start + num_samples)
+  if(codec->sample_buffer_alloc <
+     codec->sample_buffer_end - codec->sample_buffer_start + new_samples)
     {
     
-    codec->sample_buffer_alloc = codec->sample_buffer_end - codec->sample_buffer_start + num_samples;
+    codec->sample_buffer_alloc = codec->sample_buffer_end - codec->sample_buffer_start + new_samples;
     codec->sample_buffer = realloc(codec->sample_buffer, 2 * codec->sample_buffer_alloc *
                                    track_map->channels);
     }
@@ -355,14 +366,23 @@ static int decode_chunk_vbr(quicktime_t * file, int track)
                                             &packet_samples);
     if(!packet_size)
       return 0;
+
+#if LIBAVCODEC_BUILD >= 3349760
+    bytes_decoded = codec->sample_buffer_alloc -
+      (codec->sample_buffer_end - codec->sample_buffer_start);
+    bytes_decoded *= 2 * track_map->channels;
+#else
+    bytes_decoded = 0;
+#endif
+
     
     frame_bytes =
-      avcodec_decode_audio(codec->avctx,
-                           &(codec->sample_buffer[track_map->channels *
-                                                  (codec->sample_buffer_end - codec->sample_buffer_start)]),
-                           &bytes_decoded,
-                           codec->chunk_buffer,
-                           packet_size + FF_INPUT_BUFFER_PADDING_SIZE);
+      DECODE_FUNC(codec->avctx,
+                  &(codec->sample_buffer[track_map->channels *
+                                         (codec->sample_buffer_end - codec->sample_buffer_start)]),
+                  &bytes_decoded,
+                  codec->chunk_buffer,
+                  packet_size + FF_INPUT_BUFFER_PADDING_SIZE);
     if(frame_bytes < 0)
       {
       lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "avcodec_decode_audio error");
@@ -383,6 +403,7 @@ static int decode_chunk(quicktime_t * file, int track)
     
   int frame_bytes;
   int num_samples;
+  int new_samples;
   int samples_decoded = 0;
   int bytes_decoded;
   int bytes_used, bytes_skipped;
@@ -448,18 +469,18 @@ static int decode_chunk(quicktime_t * file, int track)
    */
 
   num_samples += 8192;
-
+  new_samples = num_samples + AVCODEC_MAX_AUDIO_FRAME_SIZE / (2 * track_map->channels);
+  
   /* Reallocate sample buffer */
   
-  if(codec->sample_buffer_alloc < codec->sample_buffer_end - codec->sample_buffer_start + num_samples)
+  if(codec->sample_buffer_alloc < codec->sample_buffer_end - codec->sample_buffer_start + new_samples)
     {
     
-    codec->sample_buffer_alloc = codec->sample_buffer_end - codec->sample_buffer_start + num_samples;
+    codec->sample_buffer_alloc = codec->sample_buffer_end - codec->sample_buffer_start + new_samples;
     codec->sample_buffer = realloc(codec->sample_buffer, 2 * codec->sample_buffer_alloc *
                                    track_map->channels);
     }
   
-  
   /* Decode this */
 
   bytes_used = 0;
@@ -528,9 +549,18 @@ static int decode_chunk(quicktime_t * file, int track)
      *  frame_size_ptr is zero. Otherwise, it is the decompressed frame
      *  size in BYTES.
      */
+
+#if LIBAVCODEC_BUILD >= 3349760
+    bytes_decoded = codec->sample_buffer_alloc -
+      (codec->sample_buffer_end - codec->sample_buffer_start);
+    bytes_decoded *= 2 * track_map->channels;
+#else
+    bytes_decoded = 0;
+#endif
+
     
     frame_bytes =
-      avcodec_decode_audio(codec->avctx,
+      DECODE_FUNC(codec->avctx,
                            &(codec->sample_buffer[track_map->channels *
                                                   (codec->sample_buffer_end - codec->sample_buffer_start)]),
                            &bytes_decoded,
@@ -640,9 +670,11 @@ static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long sample
     
     //  priv->ctx->block_align     = s->data.audio.block_align;
     //  priv->ctx->bit_rate        = s->codec_bitrate;
-
+#if LIBAVCODEC_VERSION_INT < ((52<<16)+(0<<8)+0)
     codec->avctx->bits_per_sample = quicktime_audio_bits(file, track);
-
+#else
+    codec->avctx->bits_per_coded_sample = quicktime_audio_bits(file, track);
+#endif
     /* Some codecs need extra stuff */
 
     if(codec->decoder->id == CODEC_ID_ALAC)
@@ -674,6 +706,7 @@ static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long sample
 
       }
 
+    
     //    memcpy(&(codec->com.ffcodec_enc), &(codec->com.params), sizeof(AVCodecContext));
     
     if(avcodec_open(codec->avctx, codec->decoder) != 0)
@@ -757,6 +790,12 @@ static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long sample
     }
   samples_decoded = codec->sample_buffer_end - codec->sample_buffer_start - samples_to_skip;
 
+  
+  if(samples_decoded <= 0)
+    {
+    track_map->last_position = track_map->current_position;
+    return 0;
+    }
   if(samples_decoded > samples)
     samples_decoded = samples;
   
