@@ -26,6 +26,7 @@
 #include <lame/lame.h>
 #include <stdlib.h>
 #include <string.h>
+#include <lame_codec.h>
 
 #define LOG_DOMAIN "lame"
 
@@ -610,7 +611,7 @@ static int encode(quicktime_t *file,
 
 
 static int set_parameter(quicktime_t *file, int track, 
-                         char *key, void *value)
+                         const char *key, const void *value)
   {
   quicktime_audio_map_t *atrack = &(file->atracks[track]);
   quicktime_mp3_codec_t *codec =
