@@ -269,7 +269,7 @@ static int next_packet(quicktime_t * file, int track)
   return 1;
   }
 
-float ** alloc_sample_buffer(float ** old, int channels, int samples,
+static float ** alloc_sample_buffer(float ** old, int channels, int samples,
                              int * sample_buffer_alloc)
   {
   int i;
@@ -753,8 +753,8 @@ static int encode(quicktime_t *file,
 
 static int set_parameter(quicktime_t *file, 
 		int track, 
-		char *key, 
-		void *value)
+		const char *key, 
+		const void *value)
 {
 	quicktime_audio_map_t *atrack = &(file->atracks[track]);
 	quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)atrack->codec)->priv;
