@@ -30,6 +30,8 @@
 #include <string.h>
 #include <strings.h>
 #include <errno.h>
+#define LQT_LIBQUICKTIME
+#include <quicktime/lqt_codecapi.h>
 
 #define LOG_DOMAIN "core"
 
@@ -166,7 +168,7 @@ int quicktime_make_streamable(char *in_path, char *out_path)
                            quicktime_position(&new_file) - moov_start)
                           {
                           lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN,
-                                  "quicktime_make_streamable: moov size changed from %lld to %lld (Pos: %lld, start: %lld)",
+                                  "quicktime_make_streamable: moov size changed from %"PRId64" to %"PRId64" (Pos: %"PRId64", start: %"PRId64")",
                                   moov_length, quicktime_position(&new_file) - moov_start,
                                   quicktime_position(&new_file), moov_start);
                           quicktime_set_position(&new_file, moov_start + moov_length);
@@ -239,13 +241,15 @@ new_file.presave_size, new_file.stream);
 
 
 
-void lqt_set_audio_parameter(quicktime_t *file,int stream, char *key,void *value)
+void lqt_set_audio_parameter(quicktime_t *file,int stream, const char *key,
+                             const void *value)
   {
   quicktime_codec_t *codec = (quicktime_codec_t*)file->atracks[stream].codec;
   if(codec->set_parameter) codec->set_parameter(file, stream, key, value);
   }
 
-void lqt_set_video_parameter(quicktime_t *file,int stream, char *key,void *value)
+void lqt_set_video_parameter(quicktime_t *file,int stream, const char *key,
+                             const void *value)
   {
   quicktime_codec_t *codec = (quicktime_codec_t*)file->vtracks[stream].codec;
   if(codec->set_parameter) codec->set_parameter(file, stream, key, value);
@@ -549,7 +553,7 @@ quicktime_trak_t* quicktime_add_track(quicktime_t *file)
     moov->trak[moov->total_tracks] =
     calloc(1, sizeof(quicktime_trak_t));
 
-  quicktime_trak_init(trak);
+  quicktime_trak_init(trak, file->file_type);
 
   moov->trak[moov->total_tracks]->tkhd.track_id = moov->mvhd.next_track_id;
   
@@ -570,7 +574,7 @@ int quicktime_init(quicktime_t *file)
 	return 0;
 }
 
-int quicktime_delete(quicktime_t *file)
+static int quicktime_delete(quicktime_t *file)
 {
 	int i;
 	if(file->total_atracks) 
@@ -939,8 +943,8 @@ void lqt_set_row_span_uv(quicktime_t *file, int track, int row_span_uv)
   {
   file->vtracks[track].io_row_span_uv = row_span_uv;
   }
-
-void quicktime_set_window(quicktime_t *file,
+#if 0
+static void quicktime_set_window(quicktime_t *file,
         int in_x,                    /* Location of input frame to take picture */
         int in_y,
         int in_w,
@@ -958,7 +962,7 @@ void quicktime_set_window(quicktime_t *file,
                 file->out_h = out_h;
         }
 }
-
+#endif
 
 void quicktime_set_depth(quicktime_t *file, int depth, int track)
 {
@@ -1192,7 +1196,8 @@ long quicktime_get_keyframe_before(quicktime_t *file, long frame, int track)
 	return 0;
 }
 
-long quicktime_get_keyframe_after(quicktime_t *file, long frame, int track)
+#if 0
+static long quicktime_get_keyframe_after(quicktime_t *file, long frame, int track)
 {
         quicktime_trak_t *trak = file->vtracks[track].track;
         quicktime_stss_t *stss = &trak->mdia.minf.stbl.stss;
@@ -1213,7 +1218,7 @@ long quicktime_get_keyframe_after(quicktime_t *file, long frame, int track)
                                                                                                                   
         return 0;
 }
-
+#endif
 
 void quicktime_insert_keyframe(quicktime_t *file, long frame, int track)
 {
@@ -1302,6 +1307,8 @@ int quicktime_delete_video_map(quicktime_video_map_t *vtrack)
 	quicktime_delete_vcodec(vtrack);
         if(vtrack->temp_frame)
           lqt_rows_free(vtrack->temp_frame);
+        if(vtrack->timecodes)
+          free(vtrack->timecodes);
 	return 0;
 }
 
@@ -1340,7 +1347,7 @@ int quicktime_delete_audio_map(quicktime_audio_map_t *atrack)
 
 void quicktime_init_maps(quicktime_t * file)
   {
-  int i, dom, track;
+  int i, j, k, dom, track;
   /* get tables for all the different tracks */
   file->total_atracks = quicktime_audio_tracks(file);
 
@@ -1395,6 +1402,28 @@ void quicktime_init_maps(quicktime_t * file)
             file->vtracks[i].interlace_mode = LQT_INTERLACE_TOP_FIRST;
           }
         }
+      /* Timecode track */
+      if(file->moov.trak[track]->has_tref)
+        {
+        for(j = 0; j < file->moov.trak[track]->tref.num_references; j++)
+          {
+          /* Track reference has type tmcd */
+          if(quicktime_match_32(file->moov.trak[track]->tref.references[j].type, "tmcd"))
+            {
+            for(k = 0; k < file->moov.total_tracks; k++)
+              {
+              if(file->moov.trak[track]->tref.references[j].tracks[0] ==
+                 file->moov.trak[k]->tkhd.track_id)
+                {
+                file->vtracks[i].timecode_track = file->moov.trak[k];
+                break;
+                }
+              }
+            break;
+            }
+          }
+        }
+      
       }
     }
 
@@ -1631,9 +1660,9 @@ int quicktime_dump(quicktime_t *file)
         if(file->has_ftyp)
           quicktime_ftyp_dump(&(file->ftyp));
 	
-        lqt_dump("movie data\n");
-	lqt_dump(" size %lld\n", file->mdat.atom.size);
-	lqt_dump(" start %lld\n", file->mdat.atom.start);
+        lqt_dump("movie data (mdat)\n");
+	lqt_dump(" size %"PRId64"\n", file->mdat.atom.size);
+	lqt_dump(" start %"PRId64"\n", file->mdat.atom.start);
 	quicktime_moov_dump(&(file->moov));
 	if (lqt_qtvr_get_object_track(file) >= 0)
 	{
@@ -1707,11 +1736,12 @@ void quicktime_set_avi(quicktime_t *file, int value)
   if(value)
     file->file_type = LQT_FILE_AVI_ODML;
   }
-                                                                                                                  
-int quicktime_is_avi(quicktime_t *file)
+#if 0                                                                                                                  
+static int quicktime_is_avi(quicktime_t *file)
 {
 return !!(file->file_type & (LQT_FILE_AVI|LQT_FILE_AVI_ODML));
 }
+#endif
 
 static quicktime_t* do_open(const char *filename, int rd, int wr, lqt_file_type_t type,
                             lqt_log_callback_t log_cb, void * log_data)
@@ -1841,19 +1871,22 @@ int quicktime_close(quicktime_t *file)
       quicktime_atom_t junk_atom;
       int64_t position = quicktime_position(file);
 #endif
-      // Finalize last header
-      quicktime_finalize_riff(file, file->riff[file->total_riffs - 1]);
-      // Finalize the odml header
-      quicktime_finalize_odml(file, &file->riff[0]->hdrl);
-
-      if(file->file_type == LQT_FILE_AVI_ODML)
+      // total_riffs is 0 if no A/V frames have been written
+      if(file->total_riffs)
         {
-        for(i = 0; i < file->moov.total_tracks; i++)
+        // Finalize last header
+        quicktime_finalize_riff(file, file->riff[file->total_riffs - 1]);
+        // Finalize the odml header
+        quicktime_finalize_odml(file, &file->riff[0]->hdrl);
+        
+        if(file->file_type == LQT_FILE_AVI_ODML)
           {
-          quicktime_finalize_indx(file, &file->moov.trak[i]->strl->indx);
+          for(i = 0; i < file->moov.total_tracks; i++)
+            {
+            quicktime_finalize_indx(file, &file->moov.trak[i]->strl->indx);
+            }
           }
         }
-      
       }
     else
       {
@@ -1929,7 +1962,7 @@ static void apply_default_parameters(quicktime_t * file,
                 parameter_info[j].name,
                 parameter_info[j].val_default.val_string);
         codec->set_parameter(file, track, parameter_info[j].name,
-                             &(parameter_info[j].val_default.val_string));
+                             parameter_info[j].val_default.val_string);
         break;
       case LQT_PARAMETER_SECTION:
         break; /* NOP */
@@ -2255,7 +2288,8 @@ sample_formats[] =
     { LQT_SAMPLE_UINT8, "8 bit unsigned" },
     { LQT_SAMPLE_INT16, "16 bit signed" },
     { LQT_SAMPLE_INT32, "32 bit signed" },
-    { LQT_SAMPLE_FLOAT, "Floating point" } /* Float is ALWAYS machine native */
+    { LQT_SAMPLE_FLOAT, "Floating point" }, /* Float is ALWAYS machine native */
+    { LQT_SAMPLE_DOUBLE, "Double precision" } /* Double is ALWAYS machine native */
   };
 
 const char * lqt_sample_format_to_string(lqt_sample_format_t format)
@@ -2514,10 +2548,17 @@ int lqt_audio_read_vbr_packet(quicktime_t * file, int track, long chunk, int pac
   /* Get offset */
   offset = trak->mdia.minf.stbl.stco.table[chunk-1].offset;
   for(i = 0; i < packet; i++)
-    offset += trak->mdia.minf.stbl.stsz.table[first_chunk_packet+i].size;
-
+    {
+    if(trak->mdia.minf.stbl.stsz.table)
+      offset += trak->mdia.minf.stbl.stsz.table[first_chunk_packet+i].size;
+    else
+      offset += trak->mdia.minf.stbl.stsz.sample_size;
+    }
   /* Get packet size */
-  packet_size = trak->mdia.minf.stbl.stsz.table[first_chunk_packet+packet].size;
+  if(trak->mdia.minf.stbl.stsz.table)
+    packet_size = trak->mdia.minf.stbl.stsz.table[first_chunk_packet+packet].size;
+  else
+    packet_size = trak->mdia.minf.stbl.stsz.sample_size;
   
   /* Get number of audio samples */
   if(samples)
