@@ -30,7 +30,8 @@
 
 */
 
-#include <lqt.h>
+
+#include <quicktime/lqt.h>
 #include <quicktime/colormodels.h>
 
 #include <config.h> // ONLY for the PACKAGE macro. Usually, applications never need
@@ -51,7 +52,6 @@
 
 #ifdef HAVE_GL
 #include <GL/gl.h>
-#include <GL/glu.h>
 #include <GL/glx.h>
 #endif
 
@@ -86,6 +86,7 @@
 static quicktime_t *qt = NULL;
 
 #define COUNT_SAMPLES
+#define DUMP_TIMECODES
 
 #ifdef COUNT_SAMPLES
 int64_t total_samples_decoded = 0;
@@ -126,6 +127,42 @@ static unsigned long   lut_red[256];
 static unsigned long   lut_green[256];
 static unsigned long   lut_blue[256];
 
+#ifdef DUMP_TIMECODES
+
+int has_timecodes = 0;
+uint32_t timecode_flags;
+int timecode_rate;
+
+static void dump_timecode(quicktime_t * file, int track, uint32_t tc)
+  {
+  int hours, minutes, seconds, frames;
+
+  if(timecode_flags & LQT_TIMECODE_DROP)
+    {
+    int64_t D, M;
+
+    D = tc / 17982;
+    M = tc % 17982;
+    tc +=  18*D + 2*((M - 2) / 1798);
+    }
+
+  frames  = tc % timecode_rate;
+  tc /= timecode_rate;
+  
+ seconds = tc % 60;
+  tc /= 60;
+  
+  minutes = tc % 60;
+  tc /= 60;
+  
+  hours   = tc % 24;
+  
+  printf("Timecode: %02d:%02d:%02d.%02d (0x%08x)\n",
+         hours, minutes, seconds, frames, tc);
+  }
+
+#endif
+
 /* Video stuff */
 
 static int qt_cmodel = BC_RGB888;
@@ -501,7 +538,7 @@ static void gl_resize(Widget widget, int width, int height)
     glViewport(0, 0, width, height);
     glMatrixMode(GL_PROJECTION);
     glLoadIdentity();
-    gluOrtho2D(0.0, width, 0.0, height);
+    glOrtho(0.0, width, 0.0, height, -1.0, 1.0);
     glMatrixMode(GL_MODELVIEW);
     glLoadIdentity();
 
@@ -647,7 +684,7 @@ static int alsa_init(char *dev, int channels, int rate)
 	fprintf(stderr, _("Error opening PCM device %s\n"), dev);
 	return 1;
     }
-    
+#if 1
     /* Allocate the snd_pcm_hw_params_t structure on the stack. */
     snd_pcm_hw_params_alloca(&hwparams);
 
@@ -675,14 +712,24 @@ static int alsa_init(char *dev, int channels, int rate)
 	fprintf(stderr, _("Error setting channels. %i (%s)\n"), channels, snd_strerror(err));
 	return 1;
     }
+
+    /* Let Alsa resample */
+    snd_pcm_hw_params_set_rate_resample(pcm_handle, hwparams, 1);
     
     /* Set sample rate. If the exact rate is not supported */
     /* by the hardware, use nearest possible rate.         */ 
-    if ((err = snd_pcm_hw_params_set_rate_near(pcm_handle, hwparams, &tmprate, 0)) < 0 ) {
+#if 1
+    if ((err = snd_pcm_hw_params_set_rate_near(pcm_handle, hwparams, &tmprate, NULL)) < 0 ) {
 	fprintf(stderr, _("Error setting sample rate (%s)\n"), snd_strerror(err));
 	return 1;
     }
-
+#else
+    
+    if ((err = snd_pcm_hw_params_set_rate(pcm_handle, hwparams, tmprate, 0)) < 0 ) {
+	fprintf(stderr, _("Error setting sample rate (%s)\n"), snd_strerror(err));
+	return 1;
+    }
+#endif
     if (tmprate != rate) fprintf(stderr,_("WARNING: Using %i Hz instead of requested rate %i Hz\n "), tmprate, rate);
     oss_sr = tmprate;
     dir = 0;
@@ -717,6 +764,17 @@ static int alsa_init(char *dev, int channels, int rate)
 	fprintf(stderr, _("Error setting HW params.(%s)\n"), snd_strerror(err));
 	return 1;
     }
+#else /* Simple pcm */
+    snd_spcm_init(pcm_handle,
+                  rate,
+                  channels,
+                  SND_PCM_FORMAT_S16_NE,
+                  SND_PCM_SUBFORMAT_STD,
+                  SND_SPCM_LATENCY_STANDARD,
+                  SND_PCM_ACCESS_RW_INTERLEAVED,
+                  SND_SPCM_XRUN_IGNORE); 		
+    
+#endif
     
     if ((err = snd_pcm_prepare(pcm_handle)) < 0) {
 	fprintf(stderr, _("Error in pcm_prepare.(%s)\n"), snd_strerror(err));
@@ -839,8 +897,10 @@ static void qt_init(FILE *fp, char *filename)
     char *adev_name;
     
     /* default */
-    adev_name = strdup("plughw");
-
+    //    adev_name = strdup("plughw");
+    //adev_name = strdup("plughw:0,0");
+    adev_name = strdup("default");
+    
     /* open file */
     qt = quicktime_open(filename,1,0);
     if (NULL == qt) {
@@ -898,6 +958,9 @@ static void qt_init(FILE *fp, char *filename)
 	qt_width  = quicktime_video_width(qt,0);
 	qt_height = quicktime_video_height(qt,0);
         qt_timescale = lqt_video_time_scale(qt,0);
+#ifdef DUMP_TIMECODES
+        has_timecodes = lqt_has_timecode_track(qt, 0, &timecode_flags, &timecode_rate);
+#endif
         fprintf(stderr, _("Timescale: %d\n"), qt_timescale);
     }
 
@@ -1110,67 +1173,83 @@ static int qt_frame_decode(void)
   int i, j, k1, k2, x2, x, y, i2;
   int pano_width = lqt_qtvr_get_width(qt);
   int pano_height = lqt_qtvr_get_height(qt);
-
-  if (qt_isqtvr == QTVR_OBJ) {
-	/* sanity check and decode  */
-	if (quicktime_video_position(qt, 0) >= 0 &&
-	    quicktime_video_position(qt, 0) < quicktime_video_length(qt,0))
-	    lqt_decode_video(qt, qt_rows, 0);
-	//    quicktime_decode_scaled(qt,0,0,qt_width,qt_height,qt_width,qt_height,
+#ifdef DUMP_TIMECODES
+  uint32_t timecode;
+#endif
+  if (qt_isqtvr == QTVR_OBJ)
+    {
+    /* sanity check and decode  */
+    if (quicktime_video_position(qt, 0) >= 0 &&
+        quicktime_video_position(qt, 0) < quicktime_video_length(qt,0))
+      lqt_decode_video(qt, qt_rows, 0);
+    //    quicktime_decode_scaled(qt,0,0,qt_width,qt_height,qt_width,qt_height,
     //			    qt_cmodel,qt_rows,0);
     }
-    else if (qt_isqtvr == QTVR_PAN) {
-		float qdist = pow(pano_width / (2 * M_PI), 2);
-		int tilt = ypos + qtvr_dheight / 2 - pano_height / 2;
-		int tmp_row_offset;
-		float hofac, hofac2;
+  else if (qt_isqtvr == QTVR_PAN)
+    {
+    float qdist = pow(pano_width / (2 * M_PI), 2);
+    int tilt = ypos + qtvr_dheight / 2 - pano_height / 2;
+    int tmp_row_offset;
+    float hofac, hofac2;
 		
-		hofac = qtvr_dheight * (qtvr_dheight - pano_height) / (-12 * qdist);
+    hofac = qtvr_dheight * (qtvr_dheight - pano_height) / (-12 * qdist);
 		
-		for (j = 0; j < qtvr_dheight; j++) {
-			tmp_row_offset = (ypos + j) * qtvr_dwidth;
-			for (i = 0; i < qtvr_dwidth; i++) {
-				k2 = i * 3;
-				k1 = (qt_frame_tmp[1][tmp_row_offset + i] * (pano_width + oh_width) +
-					  qt_frame_tmp[0][tmp_row_offset + i] + xpos) * 3;
+    for (j = 0; j < qtvr_dheight; j++)
+      {
+      tmp_row_offset = (ypos + j) * qtvr_dwidth;
+      for (i = 0; i < qtvr_dwidth; i++)
+        {
+        k2 = i * 3;
+        k1 = (qt_frame_tmp[1][tmp_row_offset + i] * (pano_width + oh_width) +
+              qt_frame_tmp[0][tmp_row_offset + i] + xpos) * 3;
 
-				qt_frame_row[k2] = qt_panorama_buffer[k1];
-				qt_frame_row[k2 + 1] = qt_panorama_buffer[k1 + 1];
-				qt_frame_row[k2 + 2] = qt_panorama_buffer[k1 + 2];
-			}
+        qt_frame_row[k2] = qt_panorama_buffer[k1];
+        qt_frame_row[k2 + 1] = qt_panorama_buffer[k1 + 1];
+        qt_frame_row[k2 + 2] = qt_panorama_buffer[k1 + 2];
+        }
+      
+      // Perspective Correction
+      // probably wrong
+      y = j - (qtvr_dheight/2);
+      hofac2 = (((y * tilt) / (qdist * 3)) + 1 - hofac);
+      for (i=0; i < qtvr_dwidth; i++)
+        {
+        x = i - (qtvr_dwidth / 2);
 			
-			// Perspective Correction
-			// probably wrong
-			y = j - (qtvr_dheight/2);
-			hofac2 = (((y * tilt) / (qdist * 3)) + 1 - hofac);
-			for (i=0; i < qtvr_dwidth; i++) {
-				x = i - (qtvr_dwidth / 2);
+        x2 = x * hofac2;
+        i2 =  (qtvr_dwidth / 2) + x2;
 			
-				x2 = x * hofac2;
-				i2 =  (qtvr_dwidth / 2) + x2;
-			
-				k2 = (j * qtvr_dwidth + i) * 3;
-				k1 = i2 * 3;
+        k2 = (j * qtvr_dwidth + i) * 3;
+        k1 = i2 * 3;
 				
-				qt_frame[k2] = qt_frame_row[k1];
-				qt_frame[k2 + 1] = qt_frame_row[k1 + 1];
-				qt_frame[k2 + 2] = qt_frame_row[k1 + 2];
-			}
-		}
+        qt_frame[k2] = qt_frame_row[k1];
+        qt_frame[k2 + 1] = qt_frame_row[k1 + 1];
+        qt_frame[k2 + 2] = qt_frame_row[k1 + 2];
+        }
+      }
     }
-    else {
-		if (quicktime_video_position(qt,0) >= quicktime_video_length(qt,0))
-			return -1;
+  else
+    {
+    if (quicktime_video_position(qt,0) >= quicktime_video_length(qt,0))
+      return -1;
 		
-		if (qt_drop) {
-			qt_droptotal += qt_drop;
-			fprintf(stderr,_("dropped %d frame(s)\r"),qt_droptotal);
-			for (i = 0; i < qt_drop; i++)
-			  	quicktime_read_frame(qt,qt_frame,0);
-			qt_drop = 0;
-		}
-		qt_frame_time = lqt_frame_time(qt, 0);
-		lqt_decode_video(qt, qt_rows, 0);
+    if (qt_drop)
+      {
+      qt_droptotal += qt_drop;
+      fprintf(stderr,_("dropped %d frame(s)\r"),qt_droptotal);
+      for (i = 0; i < qt_drop; i++)
+        quicktime_read_frame(qt,qt_frame,0);
+      qt_drop = 0;
+      }
+    qt_frame_time = lqt_frame_time(qt, 0);
+
+#ifdef DUMP_TIMECODES
+    if(lqt_read_timecode(qt, 0, &timecode))
+      dump_timecode(qt, 0, timecode);
+#endif
+    
+
+    lqt_decode_video(qt, qt_rows, 0);
 
     }
   return 0;
